@@ -1,4 +1,6 @@
-test_that("expected behavior", {
+skip_if_not_installed("vcr")
+
+test_that("get_citation() works", {
   vcr::use_cassette(name = "get_citation", {
     ref <- get_citation(get_network_by_id(18))
     netws <- get_collection(search_networks("lagoon"))
@@ -9,4 +11,6 @@ test_that("expected behavior", {
   expect_true(grepl("^@article", ref))
   expect_true(grepl("^@article", ref2[1]))
   expect_true(grepl("^@book", ref2[2]))
+  expect_snapshot(ref)
+  expect_snapshot(netws)
 })
