@@ -1,3 +1,4 @@
+skip_if_not_installed("vcr")
 # number of variables (columns)
 nvr <- 10
 
@@ -6,6 +7,7 @@ test_that("search_datasets() query and collection work", {
     res1 <- search_datasets(query = "lagoon")
     resc <- get_collection(res1)
   })
+  expect_s3_class(res1, "mgSearchDatasets")
   expect_equal(dim(res1), c(2, nvr))
   expect_equal(class(resc), "mgNetworksCollection")
   expect_equal(class(resc[[1L]]), "mgNetwork")
@@ -16,8 +18,9 @@ test_that("search_datasets() query and collection work", {
 
 test_that("search_datasets() bad input format", {
   expect_error(
-    search_datasets(query = 2011), 
-    regex = "a list or a character string\\.$")
+    search_datasets(query = 2011),
+    regex = "a list or a character string\\.$"
+  )
 })
 
 test_that("search_datasets() querying via list works", {
@@ -30,10 +33,17 @@ test_that("search_datasets() querying via list works", {
 
 test_that("search_datasets() no match works", {
   vcr::use_cassette(name = "search_datasets_empty", {
-    expect_message(res <- search_datasets(query = "does not exist"))
+    withr::local_options(list(rmangal.verbose = "verbose"))
+    expect_snapshot(res <- search_datasets(query = "does not exist"))
   })
   expect_s3_class(res, "data.frame")
   expect_equal(dim(res), c(0, 0))
 })
 
 
+test_that("search_datasets() handles 404", {
+  vcr::use_cassette(name = "search_datasets_404", {
+    expect_snapshot(res1 <- search_datasets(query = "this_is_wrong"))
+  })  
+  expect_identical(res1, data.frame())
+})
