@@ -1,3 +1,4 @@
+skip_if_not_installed("vcr")
 test_that("search_networks() default and collection work", {
   vcr::use_cassette(name = "search_networks_def", {
     res1 <- search_networks("lagoon")
@@ -10,13 +11,15 @@ test_that("search_networks() default and collection work", {
   # at least one network per dataset
   expect_true(length(resc) == nrow(res1))
   expect_equal(names(resc[[1L]]), nm_co)
+  expect_snapshot(res1)
 })
 
 test_that("search_networks_sf() spatial queries work", {
   vcr::use_cassette(name = "search_networks_spat", {
     # search_networks_sf() gets all ids, will keep growing
     # at some point the yaml might get too heavy
-    area <- sf::st_read(system.file("shape/nc.shp", package = "sf"))
+    area <- system.file("shape/nc.shp", package = "sf") |>
+      sf::st_read(quiet = TRUE)
     res <- search_networks_sf(area)
     # resc <- get_collection(res1) # don't think it's needed
   })
@@ -24,3 +27,10 @@ test_that("search_networks_sf() spatial queries work", {
   expect_s3_class(res, "sf")
   expect_equal(nrow(res), 5)
 })
+
+test_that("search_networks() handles 404", {
+  vcr::use_cassette(name = "search_networks_404", {
+    expect_snapshot(res1 <- search_networks(query = "this_is_wrong"))
+  })
+  expect_identical(res1, data.frame())
+})
